@@ -21,12 +21,8 @@
 #ifndef __NETWORKMANAGER_DEVICE_VLAN_H__
 #define __NETWORKMANAGER_DEVICE_VLAN_H__
 
-#include <glib-object.h>
-
 #include "nm-device.h"
 
-G_BEGIN_DECLS
-
 #define NM_TYPE_DEVICE_VLAN            (nm_device_vlan_get_type ())
 #define NM_DEVICE_VLAN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NM_TYPE_DEVICE_VLAN, NMDeviceVlan))
 #define NM_DEVICE_VLAN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  NM_TYPE_DEVICE_VLAN, NMDeviceVlanClass))
@@ -44,14 +40,9 @@ typedef enum {
 #define NM_DEVICE_VLAN_PARENT     "parent"
 #define NM_DEVICE_VLAN_ID         "vlan-id"
 
-/* Internal non-exported properties */
-#define NM_DEVICE_VLAN_INT_PARENT_DEVICE     "int-parent-device"
-
 typedef NMDevice NMDeviceVlan;
 typedef NMDeviceClass NMDeviceVlanClass;
 
 GType nm_device_vlan_get_type (void);
 
-G_END_DECLS
-
-#endif	/* NM_DEVICE_VLAN_H */
+#endif /* __NETWORKMANAGER_DEVICE_VLAN_H__ */
