@@ -23,9 +23,7 @@
 #include <sys/timerfd.h>
 #include <sys/wait.h>
 
-#if 0 /* NM_IGNORED */
 #include "sd-daemon.h"
-#endif
 #include "sd-event.h"
 #include "sd-id128.h"
 
@@ -34,13 +32,9 @@
 #include "hashmap.h"
 #include "list.h"
 #include "macro.h"
-#if 0 /* NM_IGNORED */
 #include "missing.h"
-#endif
 #include "prioq.h"
-#if 0 /* NM_IGNORED */
 #include "process-util.h"
-#endif
 #include "set.h"
 #include "signal-util.h"
 #include "string-table.h"
@@ -117,8 +111,8 @@ struct sd_event_source {
         int64_t priority;
         unsigned pending_index;
         unsigned prepare_index;
-        unsigned pending_iteration;
-        unsigned prepare_iteration;
+        uint64_t pending_iteration;
+        uint64_t prepare_iteration;
 
         LIST_FIELDS(sd_event_source, sources);
 
@@ -223,7 +217,7 @@ struct sd_event {
 
         pid_t original_pid;
 
-        unsigned iteration;
+        uint64_t iteration;
         triple_timestamp timestamp;
         int state;
 
@@ -2885,4 +2879,12 @@ _public_ int sd_event_get_watchdog(sd_event *e) {
 
         return e->watchdog;
 }
+
+_public_ int sd_event_get_iteration(sd_event *e, uint64_t *ret) {
+        assert_return(e, -EINVAL);
+        assert_return(!event_pid_changed(e), -ECHILD);
+
+        *ret = e->iteration;
+        return 0;
+}
 #endif /* NM_IGNORED */
